# Install ReacNetGenerator

[![Nbviewer](https://raw.githubusercontent.com/jupyter/design/master/logos/Badges/nbviewer_badge.svg)](https://nbviewer.jupyter.org/github/tongzhugroup/reacnetgenerator/blob/master/tutorial/install.ipynb?flush_cache=false)
[![Colab](https://img.njzjz.win/?url=colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/tongzhugroup/reacnetgenerator/blob/master/tutorial/install.ipynb)

In this tutorial, we will use `pip` to install ReacNetGenerator. This is the eastiest way without compiling the package. You can click the above badget to repeat it.

```bash
pip install reacnetgenerator
```

Now, ReacNetGenerator has been already installed in the environment. Try it now!

```bash
reacnetgenerator -h
```
